# Generated by roxygen2: do not edit by hand

S3method(Lfdr,GLVmix)
S3method(Lfdr,GLmix)
S3method(Lfdr,WGLVmix)
S3method(plot,GLVmix)
S3method(predict,B2mix)
S3method(predict,Bmix)
S3method(predict,GLVmix)
S3method(predict,GLmix)
S3method(predict,HLmix)
S3method(predict,Pmix)
S3method(predict,WGLVmix)
export(B2mix)
export(BDGLmix)
export(BPmix)
export(Bmix)
export(Cosslett)
export(Finv)
export(GLVmix)
export(GLmix)
export(GVmix)
export(Gammamix)
export(Gompertzmix)
export(HLmix)
export(HodgesLehmann)
export(HuberSpline)
export(KW2smooth)
export(KWDual)
export(KWPrimal)
export(KWsmooth)
export(L1norm)
export(Lfdr)
export(NPmix)
export(Pmix)
export(RLR)
export(Rxiv)
export(TLmix)
export(ThreshFDR)
export(Tncpmix)
export(Umix)
export(WGLVmix)
export(WLVmix)
export(WTLVmix)
export(Weibullmix)
export(bwKW)
export(bwKW2)
export(dhuber)
export(hubereps)
export(medde)
export(qKW)
export(qKW2)
export(qmedde)
export(rKW)
export(rmedde)
export(traprule)
import(Matrix)
importFrom(graphics,contour)
importFrom(graphics,plot)
importFrom(graphics,plot.default)
importFrom(lattice,cloud)
importFrom(methods,as)
importFrom(methods,new)
importFrom(splines,ns)
importFrom(stats,approx)
importFrom(stats,approxfun)
importFrom(stats,dbinom)
importFrom(stats,dgamma)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,dt)
importFrom(stats,dweibull)
importFrom(stats,is.stepfun)
importFrom(stats,knots)
importFrom(stats,nlm)
importFrom(stats,pnorm)
importFrom(stats,ppois)
importFrom(stats,pweibull)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,uniroot)
importFrom(stats,var)
